import request from '@/utils/request'
import { praseStrEmpty } from "@/utils/common";

// 查询用户列表
export function listUser(query) {
  return request({
    url: '/company/user/list',
    method: 'get',
    params: query
  })
}
export function getList(query) {
  return request({
    url: '/company/user/getList',
    method: 'get',
    params: query
  })
}
export function getUserList() {
  return request({
    url: '/company/user/getUserList',
    method: 'get'
  })
}
export function getUserListByDeptId(query) {
  return request({
    url: '/company/user/getUserListByDeptId',
    method: 'get',
    params: query
  })
}

export function getAddressBookList(query) {
  return request({
    url: '/company/user/getAddressBookList',
    method: 'get',
    params: query
  })
}



// 查询用户详细
export function getUser(userId) {
  return request({
    url: '/company/user/' + praseStrEmpty(userId),
    method: 'get'
  })
}

// 新增用户
export function addUser(data) {
  return request({
    url: '/company/user',
    method: 'post',
    data: data
  })
}

// 修改用户
export function updateUser(data) {
  return request({
    url: '/company/user',
    method: 'put',
    data: data
  })
}

// 删除用户
export function delUser(userId) {
  return request({
    url: '/company/user/' + userId,
    method: 'delete'
  })
}

// 导出用户
export function exportUser(query) {
  return request({
    url: '/company/user/export',
    method: 'get',
    params: query
  })
}

// 用户密码重置
export function resetUserPwd(userId, password) {
  const data = {
    userId,
    password
  }
  return request({
    url: '/company/user/resetPwd',
    method: 'put',
    data: data
  })
}

// 用户状态修改
export function changeUserStatus(userId, status) {
  const data = {
    userId,
    status
  }
  return request({
    url: '/company/user/changeStatus',
    method: 'put',
    data: data
  })
}

// 查询用户个人信息
export function getUserProfile() {
  return request({
    url: '/company/user/profile',
    method: 'get'
  })
}

// 修改用户个人信息
export function updateUserProfile(data) {
  return request({
    url: '/company/user/profile',
    method: 'put',
    data: data
  })
}

// 用户密码重置
export function updateUserPwd(oldPassword, newPassword) {
  const data = {
    oldPassword,
    newPassword
  }
  return request({
    url: '/company/user/profile/updatePwd',
    method: 'put',
    params: data
  })
}

// 用户头像上传
export function uploadAvatar(data) {
  return request({
    url: '/company/user/profile/avatar',
    method: 'post',
    data: data
  })
}

// 下载用户导入模板
export function importTemplate() {
  return request({
    url: '/company/user/importTemplate',
    method: 'get'
  })
}

export function getSelectUserList(query) {
  return request({
    url: '/company/user/getSelectUserList',
    method: 'get',
    params: query
  })
}
