import { login, logout, getInfo } from '@/api/login'
import { callMobile,callOffMobile,getSipAccount } from "@/api/company/companyVoiceApi"
import { getToken, setToken, removeToken,getDeviceId, setDeviceId,removeDeviceId } from '@/utils/auth'
import { getQwUser,qwLoginOut } from "@/api/qw/login"

const user = {
  state: {
    token: getToken(),
    name: '',
    user:undefined,
    avatar: '',
    roles: [],
    permissions: [],
    callUser:null,
    callRealm:null,
    callHa1:null,
    isCall:false,
    callTitle:null,
    deviceId:getDeviceId(),
    qwUser:null,
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
    },
    SET_USER: (state, user) => {
      state.user = user
    },
    SET_CALL_USER: (state, callUser) => {
      console.log(callUser)
      state.callUser = callUser
    },
    SET_CALL_REALM: (state, callRealm) => {
      state.callRealm = callRealm
    },
    SET_CALL_HA1: (state, callHa1) => {
      state.callHa1 = callHa1
    },
    SET_CALL: (state, call) => {
      state.isCall = call
    },
    SET_CALL_STATUS: (state, title) => {
      console.log(title)
      state.callTitle = title
    },
    SET_QW_USER: (state, qwUser) => {
      console.log("qxj SET_QW_USER:"+JSON.stringify(qwUser))
      state.qwUser = qwUser
    },

  },

  actions: {
    CallStatus({ commit }, data){
      commit('SET_CALL_STATUS', data.title)

    },
    Call({ commit }, data){
      commit('SET_CALL', true)
      commit('SET_CALL_STATUS', "正在呼叫"+data.mobile+"...")
    },
    CallOff({ commit }){
      commit('SET_CALL', false)
    },

    qwUser({ commit }, qwUser){
      console.log("qxj qwUser:"+JSON.stringify(qwUser));
      setDeviceId(qwUser.deviceId);
      commit('SET_QW_USER', qwUser);
    },
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim()
      const password = userInfo.password
      const code = userInfo.code
      const uuid = userInfo.uuid
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid).then(res => {
          setToken(res.token)
          commit('SET_TOKEN', res.token)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },
    GetSipAccount({ commit, state }) {
      return new Promise((resolve, reject) => {
        getSipAccount().then(res => {
          console.log(res)
          if(res.code==200){
            commit('SET_CALL_USER', res.data.data.response.data.user)
            commit('SET_CALL_REALM', res.data.data.response.data.realm)
            commit('SET_CALL_HA1', res.data.data.response.data.ha1)
          }
          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo(state.token).then(res => {
          const user = res.user
          const avatar = user.avatar == "" ? require("@/assets/image/profile.jpg") : process.env.VUE_APP_BASE_API + user.avatar;
          if (res.roles && res.roles.length > 0) { // 验证返回的roles是否是一个非空数组
            commit('SET_ROLES', res.roles)
            commit('SET_PERMISSIONS', res.permissions)
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT'])
          }
          commit('SET_NAME', user.userName)
          commit('SET_AVATAR', avatar)
          commit('SET_USER', user)
          
          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },


    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          commit('SET_PERMISSIONS', [])
          removeToken()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    },


    //获取企微用户信息
    getQwUserInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        if(!state.deviceId){
           resolve("");
           return;
        }
        getQwUser(state.deviceId).then(res => {
          if(res.code==200){
            const qwUser = res.data
            commit('SET_QW_USER', qwUser);
          }else{
            commit('SET_QW_USER', "");
          }
          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },
    
     //企微退出系统
     qwLoginOut({ commit, state }) {
          return new Promise((resolve, reject) => {
            qwLoginOut(state.deviceId).then(() => {
              commit('SET_QW_USER', "");
              removeDeviceId()
              resolve()
            }).catch(error => {
              reject(error)
            })
          })
      }
  }
}

export default user
